@@ -2,9 +2,10 @@ from .response_wrapper import ResponseWrap
 from .extractor import Extractor
 from .validator import Validator
 from .boot import Boot
+from .driver import MiniTestDriver
 
 __author__ = "shigebeyond"
-__version__ = "1.0.0"
+__version__ = "1.0.1"
 __description__ = "MiniumBoot: make an easy way (yaml) to wechat miniprogram automation testing"
 
 __all__ = [
@@ -15,4 +16,5 @@ __all__ = [
     "Extractor",
     "Validator",
     "Boot",
+    "MiniTestDriver",
 ]
\ No newline at end of file
