@@ -19,7 +19,7 @@ from minium.framework.miniconfig import MiniConfig
 from minium.framework.assertbase import AssertBase
 from at.core.adbwrap import AdbWrap
 from minium.native.wx_native.androidnative import WXAndroidNative
-from driver import MiniTestDriver
+from MiniumBoot.driver import MiniTestDriver
 
 # 扩展BaseElement方法
 def get_value_or_text(self):
@@ -124,6 +124,7 @@ class Boot(object):
             'extract_by_xpath': self.extract_by_xpath,
             'extract_by_id': self.extract_by_id,
             'extract_by_eval': self.extract_by_eval,
+            'exec': self.exec,
 
             # 以下步骤是根据官方api封装, 但发现api无用
             'swipe': self.swipe,
@@ -303,7 +304,7 @@ class Boot(object):
         self.appjson = read_json(path)
 
         # TestSuite
-        self.suite = minium.framework.loader.load_from_case_name('driver', 'test_boot')
+        self.suite = minium.framework.loader.load_from_case_name('MiniumBoot.driver', 'test_boot')
         # driver.MiniTestDriver
         self.driver = self.suite._tests[0]
 
@@ -1147,6 +1148,11 @@ class Boot(object):
         # 缩小: 从两边到中间
         return 9.9, 0.1, 0.5, 0.5
 
+    # 执行命令
+    def exec(self, cmd):
+        output = os.popen(cmd).read()
+        log.debug(f"执行命令: {cmd} | 结果: {output}")
+
 
 # cli入口
 def main():
